@@ -51,7 +51,7 @@ class ManageConsumers():
             return
 
         try:
-            self.handler(str(message))
+            self.handler(message)
             _logger.info(f"publishing at : { self.successful_job_routing_key}")
             channel.basic_publish(exchange=self.exchange_name, routing_key=self.successful_job_routing_key, body=json.dumps(message))
         except Exception as err:
